@@ -6,7 +6,7 @@
 pref("extensions.enigmail.configuredVersion","");
 
 // additional parameter(s) to pass to GnuPG
-pref("extensions.enigmail.agentAdditionalParam","--charset utf8");
+pref("extensions.enigmail.agentAdditionalParam","");
 
 // path to gpg executable
 pref("extensions.enigmail.agentPath","");
@@ -20,6 +20,9 @@ pref("extensions.enigmail.allowEmptySubject",false);
 // not (yet) in use
 pref("extensions.enigmail.autoCrypto",false);
 
+// automatically download missing keys from keyserver
+pref("extensions.enigmail.autoKeyRetrieve","");
+
 // enable automatically decrypt/verify
 pref("extensions.enigmail.autoDecrypt",true);
 
@@ -50,10 +53,13 @@ pref("extensions.enigmail.doubleDashSeparator",true);
 // last state of dialog to choose encryption method if there are attachments
 pref("extensions.enigmail.encryptAttachments",1);
 
+// skip the attachments dialog
+pref("extensions.enigmail.encryptAttachmentsSkipDlg", 0);
+
 // Encrypt to self
 pref("extensions.enigmail.encryptToSelf",true);
 
-// warn if GnuPG <= v1.0.6 (countdown)
+// warn if GnuPG <= v1.2.0 (countdown)
 pref("extensions.enigmail.gpgVersionWarnCount",1);
 
 // enable 'Decrypt & open' for double click on attachment (if possible)
@@ -62,8 +68,8 @@ pref("extensions.enigmail.handleDoubleClick",false);
 // disable '<' and '>' around email addresses
 pref("extensions.enigmail.hushMailSupport",false);
 
-// countdown for 'failed to initialize enigmime'
-pref("extensions.enigmail.initAlertCount",2);
+// display alert for 'failed to initialize enigmime'
+pref("extensions.enigmail.initAlert",true);
 
 // use -a for encrypting attachments for inline PGP
 pref("extensions.enigmail.inlineAttachAsciiArmor",false);
@@ -74,11 +80,11 @@ pref("extensions.enigmail.inlineAttachExt",".pgp");
 // debug log directory (if set, also enabled debugging)
 pref("extensions.enigmail.logDirectory","");
 
-// enable encrypten for replies to encrypted mails
+// enable encryption for replies to encrypted mails
 pref("extensions.enigmail.keepSettingsForReply",true);
 
 // list of keyservers to use
-pref("extensions.enigmail.keyserver","random.sks.keyserver.penguin.de, pgp.dtype.org, keyserver.kjsl.com, ldap://certserver.pgp.com");
+pref("extensions.enigmail.keyserver","random.sks.keyserver.penguin.de, subkeys.pgp.net, pgp.mit.edu, ldap://certserver.pgp.com");
 
 // keep passphrase for ... minutes
 pref("extensions.enigmail.maxIdleMinutes",5);
@@ -134,6 +140,9 @@ pref("extensions.enigmail.warnOnRulesConflict",0);
 // display a warning when the passphrase is cleared
 pref("extensions.enigmail.warnClearPassphrase",true);
 
+// display a warning when all keys are to be refreshed
+pref("extensions.enigmail.warnRefreshAll",true);
+
 // wrap HTML messages before sending inline PGP messages
 pref("extensions.enigmail.wrapHtmlBeforeSend",true);
 
