@@ -39,6 +39,7 @@
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
+#define MOZILLA_INTERNAL_API
 #include "nspr.h"
 #include "nsCOMPtr.h"
 #include "nsString.h"
@@ -54,7 +55,7 @@
 #include "nsIPipeTransport.h"
 #include "nsIIPCBuffer.h"
 #include "nsIEnigmail.h"
-
+#undef MOZILLA_INTERNAL_API
 #ifdef PR_LOGGING
 PRLogModuleInfo* gEnigMimeVerifyLog = NULL;
 #endif
@@ -113,8 +114,8 @@ nsEnigMimeVerify::nsEnigMimeVerify()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigMimeVerify:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsEnigMimeVerify:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 }
 
@@ -125,8 +126,8 @@ nsEnigMimeVerify::~nsEnigMimeVerify()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigMimeVerify:: >>>>>>>>> DTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsEnigMimeVerify:: >>>>>>>>> DTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
   Finalize();
@@ -331,7 +332,7 @@ temBoundary += "--";
         headerSink->GetSecurityInfo(getter_AddRefs(securityInfo));
   }
 
-  DEBUG_LOG(("nsEnigMimeVerify::Finish: securityInfo=%x\n", securityInfo.get()));
+  DEBUG_LOG(("nsEnigMimeVerify::Finish: securityInfo=%p\n", securityInfo.get()));
 
   if (securityInfo) {
     nsCOMPtr<nsIEnigMimeHeaderSink> enigHeaderSink = do_QueryInterface(securityInfo);
@@ -425,6 +426,15 @@ nsEnigMimeVerify::OnStartRequest(nsIRequest *aRequest,
   } else if (contentMicalg.EqualsIgnoreCase("pgp-ripemd160")) {
     hashSymbol = "RIPEMD160";
 
+  } else if (contentMicalg.EqualsIgnoreCase("pgp-sha256")) {
+    hashSymbol = "SHA256";
+    
+  } else if (contentMicalg.EqualsIgnoreCase("pgp-sha384")) {
+    hashSymbol = "SHA384";
+
+  } else if (contentMicalg.EqualsIgnoreCase("pgp-sha512")) {
+    hashSymbol = "SHA512";
+
   } else {
     ERROR_LOG(("nsEnigMimeVerify::OnStartRequest: ERROR contentMicalg='%s'\n", contentMicalg.get()));
     return NS_ERROR_FAILURE;
@@ -484,7 +494,7 @@ nsEnigMimeVerify::OnStartRequest(nsIRequest *aRequest,
     mMsgWindow->GetPromptDialog(getter_AddRefs(prompter));
   }
 
-  DEBUG_LOG(("nsEnigMimeVerify::OnStartRequest: prompter=%x\n", prompter.get()));
+  DEBUG_LOG(("nsEnigMimeVerify::OnStartRequest: prompter=%p\n", prompter.get()));
 
   nsCOMPtr<nsIEnigmail> enigmailSvc = do_GetService(NS_ENIGMAIL_CONTRACTID, &rv);
   if (NS_FAILED(rv)) return rv;
@@ -593,7 +603,7 @@ nsEnigMimeVerify::OnDataAvailable(nsIRequest* aRequest,
     readMax = (aLength < kCharMax) ? aLength : kCharMax;
     rv = aInputStream->Read((char *) buf, readMax, &readCount);
     if (NS_FAILED(rv)){
-      DEBUG_LOG(("nsEnigMimeVerify::OnDataAvailable: Error in reading from input stream, %x\n", rv));
+      DEBUG_LOG(("nsEnigMimeVerify::OnDataAvailable: Error in reading from input stream, %p\n", rv));
       return rv;
     }
 
