@@ -34,8 +34,8 @@ GPL.
 // enigmailCommon.js: shared JS functions for Enigmail
 
 // This Enigmail version and compatible Enigmime version
-var gEnigmailVersion = "0.93.2.0";
-var gEnigmimeVersion = "0.93.2.0";
+var gEnigmailVersion = "0.94.0.0";
+var gEnigmimeVersion = "0.94.0.0";
 
 // Maximum size of message directly processed by Enigmail
 const ENIG_MSG_BUFFER_SIZE = 96000;
@@ -1391,6 +1391,45 @@ function EnigRulesEditor() {
               "dialog,centerscreen,resizable");
 }
 
+function EnigOpenSetupWizard() {
+  window.open("chrome://enigmail/content/enigmailSetupWizard.xul",
+            "", "chrome,modal,centerscreen");
+}
+
+// get keys from keyserver
+function EnigDownloadKeys(inputObj, resultObj) {
+  DEBUG_LOG("enigmailCommon.js: EnigSearchKeys: searchList="+inputObj.searchList+"\n");
+  
+  resultObj.importedKeys=0;
+
+  var ioService = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+  if (ioService && ioService.offline) {
+    EnigAlert(EnigGetString("needOnline"));
+    return;
+  }
+
+  var valueObj = {};
+  if (inputObj.searchList) {
+    valueObj = { keyId: "<"+inputObj.searchList.join("> <")+">" };
+  }
+
+  var keysrvObj = new Object();
+
+  window.openDialog("chrome://enigmail/content/enigmailKeyserverDlg.xul",
+        "", "dialog,modal,centerscreen", valueObj, keysrvObj);
+  if (! keysrvObj.value) {
+    return;
+  }
+  
+  inputObj.keyserver = keysrvObj.value;
+  if (! inputObj.searchList) {
+    inputObj.searchList = keysrvObj.email.split(/[,; ]+/);
+  }
+
+  window.openDialog("chrome://enigmail/content/enigmailSearchKey.xul",
+        "", "dialog,modal,centerscreen", inputObj, resultObj);
+}
+
 // create new PGP Rule
 function EnigNewRule(emailAddress) {    
   // make sure the rules database is loaded
@@ -1470,6 +1509,7 @@ function EnigLoadKeyList(refresh, keyListObj) {
 
   var keyObj = new Object();
   var i;
+  var uatNum=0; // counter for photos (counts per key)
 
   for (i=0; i<aGpgUserList.length; i++) {
     var listRow=aGpgUserList[i].split(/:/);
@@ -1477,6 +1517,7 @@ function EnigLoadKeyList(refresh, keyListObj) {
       switch (listRow[0]) {
       case "pub":
         keyObj = new Object();
+        uatNum = 0;
         keyObj.expiry=EnigGetDateTime(listRow[EXPIRY], true, false);
         keyObj.created=EnigGetDateTime(listRow[CREATED], true, false);
         keyObj.keyId=listRow[KEY_ID];
@@ -1512,8 +1553,12 @@ function EnigLoadKeyList(refresh, keyListObj) {
       case "uat":
         if (listRow[USER_ID].indexOf("1 ")==0) {
           var userId=EnigGetString("userAtt.photo");
-          keyObj.SubUserIds.push({userId: userId, keyTrust:"", type: "uat"});
+          keyObj.SubUserIds.push({userId: userId,
+                                  keyTrust:listRow[KEY_TRUST],
+                                  type: "uat",
+                                  uatNum: uatNum});
           keyObj.photoAvailable=true;
+          ++uatNum;
         }
       }
     }
@@ -1553,12 +1598,13 @@ function EnigSignKey(userId, keyId, signingKeyHint) {
   window.openDialog("chrome://enigmail/content/enigmailSignKeyDlg.xul","", "dialog,modal,centerscreen,resizable", inputObj);
 }
 
-function EnigShowPhoto(keyId, userId) {
+function EnigShowPhoto(keyId, userId, photoNumber) {
   var enigmailSvc = GetEnigmailSvc();
   if (enigmailSvc) {
+    if (photoNumber==null) photoNumber=0;
     var exitCodeObj = new Object();
     var errorMsgObj = new Object();
-    var photoPath = enigmailSvc.showKeyPhoto("0x"+keyId, exitCodeObj, errorMsgObj);
+    var photoPath = enigmailSvc.showKeyPhoto("0x"+keyId, photoNumber, exitCodeObj, errorMsgObj);
     if (photoPath && exitCodeObj.value==0) {
       var photoFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
       photoFile.initWithPath(photoPath);
@@ -1705,8 +1751,3 @@ function enigGetService (aURL, aInterface)
   
   return null;
 }
-
-function EnigOpenSetupWizard() {
-  window.open("chrome://enigmail/content/enigmailSetupWizard.xul",
-            "", "chrome,modal,centerscreen");
-}
