@@ -175,6 +175,9 @@ function enigUserSelCreateRow (keyObj, subKeyNum) {
       keyObj.SubUserIds[subKeyNum].userId = EnigConvertGpgToUnicode(keyObj.SubUserIds[subKeyNum].userId);
       userCol.setAttribute("label", keyObj.SubUserIds[subKeyNum].userId);
       treeItem.setAttribute("keytype", keyObj.SubUserIds[subKeyNum].type);
+      if (keyObj.SubUserIds[subKeyNum].type == "uat") {
+        treeItem.setAttribute("uatNum", keyObj.SubUserIds[subKeyNum].uatNum);
+      }
       keyCol.setAttribute("label", "");
       typeCol.setAttribute("label", "");
       keyTrust = keyObj.SubUserIds[subKeyNum].keyTrust;
@@ -202,7 +205,7 @@ function enigUserSelCreateRow (keyObj, subKeyNum) {
       keyTrustStyle="enigmail_keyTrust_untrusted";
       break;
     case 'm':
-      keyTrust="enigmail_keyTrust_marginal";
+      keyTrustStyle="enigmail_keyTrust_marginal";
       break;
     case 'f':
       keyTrustStyle="enigmail_keyTrust_full";
@@ -358,6 +361,7 @@ function enigmailDblClick(event) {
   }
   var keyList = enigmailGetSelectedKeys();
   var keyType="";
+  var uatNum="";
   if (keyList.length == 1) {
     var rangeCount = gUserList.view.selection.getRangeCount();
     var start = {};
@@ -365,11 +369,12 @@ function enigmailDblClick(event) {
     gUserList.view.selection.getRangeAt(0,start,end);
     try {
       keyType = gUserList.view.getItemAtIndex(start.value).getAttribute("keytype");
+      uatNum = gUserList.view.getItemAtIndex(start.value).getAttribute("uatNum");
     }
     catch(ex) {}
   }
   if (keyType=="uat") {
-    enigShowPhoto();
+    enigShowPhoto(uatNum);
   }
   else {
    enigmailKeyDetails();
@@ -454,10 +459,10 @@ function enigmailEnableKey() {
   enigmailRefreshKeys();
 }
 
-function enigShowPhoto() {
+function enigShowPhoto(uatNumber) {
   var keyList = enigmailGetSelectedKeys();
 
-  EnigShowPhoto(keyList[0], gKeyList[keyList[0]].userId);
+  EnigShowPhoto(keyList[0], gKeyList[keyList[0]].userId, uatNumber);
 }
 
 function enigCreateKeyMsg() {
@@ -511,15 +516,29 @@ function enigCreateKeyMsg() {
   // create Msg
   var msgCompFields = Components.classes["@mozilla.org/messengercompose/composefields;1"].createInstance(Components.interfaces.nsIMsgCompFields);
   msgCompFields.addAttachment(keyAttachment);
-
+  
   var acctManager = Components.classes["@mozilla.org/messenger/account-manager;1"].createInstance(Components.interfaces.nsIMsgAccountManager);
   
   var msgCompSvc = Components.classes["@mozilla.org/messengercompose;1"].getService(Components.interfaces.nsIMsgComposeService);
-  msgCompSvc.OpenComposeWindowWithCompFields ("",
+
+  if (typeof(msgCompSvc.OpenComposeWindowWithCompFields) != "function") {
+    // TB 1.5
+    var msgCompParam = Components.classes["@mozilla.org/messengercompose/composeparams;1"].createInstance(Components.interfaces.nsIMsgComposeParams);
+    msgCompParam.composeFields = msgCompFields;
+    msgCompParam.identity = acctManager.defaultAccount.defaultIdentity;
+    msgCompParam.type = Components.interfaces.nsIMsgCompType.New;
+    msgCompParam.format = Components.interfaces.nsIMsgCompFormat.Default;
+    msgCompParam.originalMsgURI = "";
+    msgCompSvc.OpenComposeWindowWithParams("", msgCompParam);
+  }
+  else {
+    // TB 1.0
+    msgCompSvc.OpenComposeWindowWithCompFields ("",
             Components.interfaces.nsIMsgCompType.New,
             Components.interfaces.nsIMsgCompFormat.Default,
             msgCompFields,
             acctManager.defaultAccount.defaultIdentity);
+  }
 }
 
 
@@ -683,9 +702,8 @@ function enigmailSearchKeys () {
     searchList : ""
   };
   var resultObj = new Object();
-  
-  window.openDialog("chrome://enigmail/content/enigmailSearchKey.xul",
-        "", "dialog,modal,centerscreen", inputObj, resultObj);
+
+  EnigDownloadKeys(inputObj, resultObj);
         
   if (resultObj.importedKeys > 0) {
     enigmailRefreshKeys();
@@ -721,6 +739,20 @@ function enigmailManageUids() {
   enigmailRefreshKeys();
 }
 
+function enigmailChangePwd() {
+  var keyList = enigmailGetSelectedKeys();
+  var inputObj = {
+    keyId: keyList[0],
+    userId: gKeyList[keyList[0]].userId
+  };
+  
+  window.openDialog("chrome://enigmail/content/enigmailChangePasswd.xul",
+        "", "dialog,modal,centerscreen", inputObj);
+
+
+}
+
+
 function enigGetClipboard() {
   DEBUG_LOG("enigmailKeyManager.js: enigGetClipboard:\n");
   var cBoardContent = "";
@@ -795,8 +827,7 @@ function enigmailSearchKey() {
   };
   var resultObj = new Object();
   
-  window.openDialog("chrome://enigmail/content/enigmailSearchKey.xul",
-        "", "dialog,modal,centerscreen", inputObj, resultObj);
+  EnigDownloadKeys(inputObj, resultObj);
         
   if (resultObj.importedKeys > 0) {
     enigmailRefreshKeys();
