@@ -1,10 +1,41 @@
+/*
+The contents of this file are subject to the Mozilla Public
+License Version 1.1 (the "MPL"); you may not use this file
+except in compliance with the MPL. You may obtain a copy of
+the MPL at http://www.mozilla.org/MPL/
+
+Software distributed under the MPL is distributed on an "AS
+IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+implied. See the MPL for the specific language governing
+rights and limitations under the MPL.
+
+The Original Code is Enigmail.
+
+The Initial Developer of the Original Code is Ramalingam Saravanan.
+Portions created by Ramalingam Saravanan <svn@xmlterm.org> are
+Copyright (C) 2002 Ramalingam Saravanan. All Rights Reserved.
+
+Contributor(s):
+Patrick Brunschwig <patrick.brunschwig@gmx.net>
+
+Alternatively, the contents of this file may be used under the
+terms of the GNU General Public License (the "GPL"), in which case
+the provisions of the GPL are applicable instead of
+those above. If you wish to allow use of your version of this
+file only under the terms of the GPL and not to allow
+others to use your version of this file under the MPL, indicate
+your decision by deleting the provisions above and replace them
+with the notice and other provisions required by the GPL.
+If you do not delete the provisions above, a recipient
+may use your version of this file under either the MPL or the
+GPL.
+*/
+
 // Uses: chrome://enigmail/content/enigmailCommon.js
 
 // Initialize enigmailCommon
 EnigInitCommon("enigmailKeygen");
 
-const ENIG_ACCOUNT_MANAGER_CONTRACTID = "@mozilla.org/messenger/account-manager;1";
-
 var gAccountManager = Components.classes[ENIG_ACCOUNT_MANAGER_CONTRACTID].getService(Components.interfaces.nsIMsgAccountManager);
 
 var gAutoCrypto;
@@ -54,6 +85,7 @@ function enigmailKeygenUnload() {
    enigmailKeygenCloseRequest();
 }
 
+
 function enigmailKeygenUpdate(getPrefs, setPrefs) {
   DEBUG_LOG("enigmailKeygen.js: Update: "+getPrefs+", "+setPrefs+"\n");
 
@@ -72,10 +104,12 @@ function enigmailKeygenUpdate(getPrefs, setPrefs) {
   passphrase1.disabled = noPassphraseChecked;
   passphrase2.disabled = noPassphraseChecked;
 
-  if (gAutoCrypto) {
-    var commentElement = document.getElementById("keyComment");
-    commentElement.value = "Enigmail auto crypto";
-    commentElement.disabled = true;
+  var commentElement = document.getElementById("keyComment")
+  if (noPassphraseChecked) {
+    if (commentElement.value == "") commentElement.value = EnigGetString("keyGenNoPassphrase");
+  }
+  else {
+    if (commentElement.value == EnigGetString("keyGenNoPassphrase")) commentElement.value = "";
   }
 }
 
@@ -85,6 +119,10 @@ function enigmailKeygenTerminate(terminateArg, ipcRequest) {
    // Give focus to this window
    window.focus();
 
+   if (!ipcRequest.pipeTransport) {
+      // changed interface in TB 1.1
+      ipcRequest = ipcRequest.QueryInterface(Components.interfaces.nsIIPCRequest);
+   }
    var keygenProcess = ipcRequest.pipeTransport;
    var enigmailSvc = GetEnigmailSvc();
    if (!enigmailSvc) {
@@ -102,9 +140,9 @@ function enigmailKeygenTerminate(terminateArg, ipcRequest) {
    enigRefreshConsole();
 
    ipcRequest.close(true);
+   var curId = gUsedId;
 
    if (gUseForSigning.checked) {
-      var curId = gUsedId;
       curId.setBoolAttribute("enablePgp", true);
       curId.setIntAttribute("pgpKeyMode", 1);
       if (gGeneratedKey) {
@@ -118,15 +156,19 @@ function enigmailKeygenTerminate(terminateArg, ipcRequest) {
 
       EnigSavePrefs();
 
-      if (EnigConfirm(EnigGetString("genComplete", curId.email))) {
-        EnigCreateRevokeCert(gGeneratedKey, curId.email);
-      }
-      
-
+     if (gGeneratedKey) {
+       if (EnigConfirm(EnigGetString("keygenComplete", curId.email)+"\n\n"+EnigGetString("revokeCertRecommended"))) {
+          EnigCreateRevokeCert(gGeneratedKey, curId.email);
+       }
+     }
    } else {
-      EnigAlert(EnigGetString("genCompleteNoSign"));
+     if (gGeneratedKey) {
+       if (EnigConfirm(EnigGetString("genCompleteNoSign")+"\n\n"+EnigGetString("revokeCertRecommended"))) {
+          EnigCreateRevokeCert(gGeneratedKey, curId.email);
+       }
+     }
    }
-
+   
    enigmailKeygenCloseRequest();
 
    enigmailSvc.invalidateUserIdList();
@@ -156,6 +198,26 @@ function enigmailKeygenCloseRequest() {
   }
 }
 
+function enigmailCheckPassphrase() {
+  var passphraseElement = document.getElementById("passphrase");
+  var passphrase2Element = document.getElementById("passphraseRepeat");
+
+  var passphrase = passphraseElement.value;
+
+  if (passphrase != passphrase2Element.value) {
+    EnigAlert(EnigGetString("passNoMatch"));
+    return null;
+  }
+
+  if (passphrase.search(/[\x80-\xFF]/)>=0) {
+    EnigAlert(EnigGetString("passCharProblem"));
+    return null;
+  }
+  return passphrase;
+}
+
+
+
 function enigmailKeygenStart() {
    DEBUG_LOG("enigmailKeygen.js: Start\n");
 
@@ -170,20 +232,8 @@ function enigmailKeygenStart() {
       return;
    }
 
-   var passphraseElement = document.getElementById("passphrase");
-   var passphrase2Element = document.getElementById("passphraseRepeat");
-
-   var passphrase = passphraseElement.value;
-
-   if (passphrase != passphrase2Element.value) {
-      EnigAlert(EnigGetString("passNoMatch"));
-      return;
-   }
-
-   if (passphrase.search(/[\x80-\xFF]/)>=0) {
-      EnigAlert(EnigGetString("passCharProblem"));
-      return;
-   }
+   var passphrase = enigmailCheckPassphrase();
+   if (passphrase == null) return;
    
    var noPassphraseElement = document.getElementById("noPassphrase");
 
@@ -195,12 +245,6 @@ function enigmailKeygenStart() {
    var commentElement = document.getElementById("keyComment");
    var comment = commentElement.value;
 
-   if (!passphrase) {
-      if (comment)
-        comment += "; ";
-      comment += "no password";
-   }
-
    var noExpiry = document.getElementById("noExpiry");
    var expireInput = document.getElementById("expireInput");
    var timeScale = document.getElementById("timeScale");
@@ -212,9 +256,14 @@ function enigmailKeygenStart() {
         EnigAlert(EnigGetString("expiryTooLong"));
         return;
       }
+      if (! (expiryTime > 0)) {
+        EnigAlert(EnigGetString("expiryTooShort"));
+        return;
+      }
    }
    var keySize = Number(document.getElementById("keySize").value);
-
+   var keyType = Number(document.getElementById("keyType").value);
+   
    var curId = getCurrentIdentity();
    gUsedId = curId;
 
@@ -244,18 +293,19 @@ function enigmailKeygenStart() {
 
    try {
       ipcRequest = enigmailSvc.generateKey(window,
-                                           userName,
-                                           comment,
+                                           EnigConvertFromUnicode(userName),
+                                           EnigConvertFromUnicode(comment),
                                            userEmail,
                                            expiryTime,
                                            keySize,
+                                           keyType,
                                            passphrase,
                                            requestObserver);
    } catch (ex) {
    }
 
    if (!ipcRequest) {
-      EnigAlert("Key generation failed!");
+      EnigAlert(EnigGetString("keyGenFailed"));
    }
 
    gKeygenRequest = ipcRequest;
@@ -280,23 +330,19 @@ function enigRefreshConsole() {
     if (keygenConsole && keygenConsole.hasNewData()) {
       DEBUG_LOG("enigmailKeygen.js: enigRefreshConsole(): hasNewData\n");
 
-      var contentFrame = EnigGetFrame(window, "keygenConsole");
-      if (contentFrame) {
-
-        var consoleElement = contentFrame.document.getElementById('console');
-
-        gAllData += keygenConsole.getNewData();
-        var keyCreatedIndex = gAllData.indexOf("[GNUPG:] KEY_CREATED");
-        if (keyCreatedIndex >0) {
-          gGeneratedKey = gAllData.substr(keyCreatedIndex);
-          gGeneratedKey = gGeneratedKey.replace(/(.*\[GNUPG:\] KEY_CREATED . )([a-fA-F0-9]+)([\n\r].*)*/, "$2");
-          gAllData = gAllData.replace(/\[GNUPG:\] KEY_CREATED . [a-fA-F0-9]+[\n\r]/, "");
-        }
-        gAllData = gAllData.replace(/[\r\n]*\[GNUPG:\] GOOD_PASSPHRASE/g, "").replace(/([\r\n]*\[GNUPG:\] PROGRESS primegen )(.)( \d+ \d+)/g, "$2")
-        consoleElement.firstChild.data = gAllData.replace(/(.{70})/g, "$1\n");
-        if (!contentFrame.mouseDownState)
-          contentFrame.scrollTo(0,9999);
+      gAllData += keygenConsole.getNewData();
+      var keyCreatedIndex = gAllData.indexOf("[GNUPG:] KEY_CREATED");
+      if (keyCreatedIndex >0) {
+        gGeneratedKey = gAllData.substr(keyCreatedIndex);
+        gGeneratedKey = gGeneratedKey.replace(/(.*\[GNUPG:\] KEY_CREATED . )([a-fA-F0-9]+)([\n\r].*)*/, "$2");
+        gAllData = gAllData.replace(/\[GNUPG:\] KEY_CREATED . [a-fA-F0-9]+[\n\r]/, "");
       }
+      gAllData = gAllData.replace(/[\r\n]*\[GNUPG:\] GOOD_PASSPHRASE/g, "").replace(/([\r\n]*\[GNUPG:\] PROGRESS primegen )(.)( \d+ \d+)/g, "$2")
+      var progMeter = document.getElementById("keygenProgress");
+      var progValue = Number(progMeter.value);
+      progValue += (1+(100-progValue)/20);
+      if (progValue >= 95) progValue=10;
+      progMeter.setAttribute("value", progValue);
     }
   } catch (ex) {}
 }
