@@ -543,25 +543,25 @@ function enigMessageDecrypt(event, isAuto) {
     xEnigmailVersion = gEnigSavedHeaders["x-enigmail-version"];
   }
 
-  var enigmailSvc = GetEnigmailSvc();
-  if (!enigmailSvc)
-    return;
+  var enigmailSvc;
     
   if (isAuto && (! EnigGetPref("autoDecrypt"))) {
     var signedMsg = ((contentType.search(/^multipart\/signed(;|$)/i) == 0) && (contentType.search(/application\/pgp-signature/i)>0));
     var encrypedMsg = ((contentType.search(/^multipart\/encrypted(;|$)/i) == 0) && (contentType.search(/application\/pgp-encrypted/i)>0));
     if (embeddedSigned || embeddedEncrypted || 
         encrypedMsg || signedMsg) {
-  
-      if (
-          (!enigmailSvc.mimeInitialized() && encrypedMsg) || signedMsg ||
+      enigmailSvc = GetEnigmailSvc();
+      if (!enigmailSvc)
+        return;
+        
+      if ((!enigmailSvc.mimeInitialized() && encrypedMsg) || signedMsg ||
           ((!encrypedMsg) && (embeddedSigned || embeddedEncrypted))) {
         enigUpdateHdrIcons(ENIG_POSSIBLE_PGPMIME, 0, "", "", "", EnigGetString("possiblyPgpMime"));
       }
     }
     return;
   }
-
+  
   EnigShowHeadersAll(false);
 
   if (((contentType.search(/^multipart\/encrypted(;|$)/i) == 0) ||
@@ -569,23 +569,28 @@ function enigMessageDecrypt(event, isAuto) {
        && (!embeddedSigned)) {
     // multipart/encrypted
     DEBUG_LOG("enigmailMessengerOverlay.js: multipart/encrypted\n");
+    enigmailSvc = GetEnigmailSvc();
+    if (!enigmailSvc)
+      return;
 
     if (!enigmailSvc.mimeInitialized()) {
       // Display enigmail:dummy URL in message pane to initialize
 
       // Need to add event listener to gEnigMessagePane to make it work
       // Adding to msgFrame doesn't seem to work
-      gEnigMessagePane.addEventListener("load",   enigMimeInit, true);
+      gEnigMessagePane.addEventListener("load", enigMimeInit, true);
       gEnigRemoveListener = true;
 
       DEBUG_LOG("enigmailMessengerOverlay.js: loading enigmail:dummy ...\n");
       gEnigNoShowReload = true;
 
       var msgFrame = EnigGetFrame(window, "messagepane");
-      //msgFrame.location = "enigmail:dummy";
       messenger.loadURL(msgFrame, "enigmail:dummy");
 
     }
+    else if (! isAuto) {
+      enigMessageReload(false);
+    }
     return;
   }
 
@@ -1462,41 +1467,6 @@ function enigKeyRequestCallback(callbackArg, ctxt) {
   // NEED TO EXTRACT KEY ETC.
 }
 
-function enigOnShowAttachmentContextMenu() {
-  // if no attachments are selected, disable the Open and Save...
-  // this is Messenger's onShowAttachmentContextMenu, extended by
-  // Enigmail specific stuff!
-  var attachmentList = document.getElementById('attachmentList');
-  var selectedAttachments = attachmentList.selectedItems;
-  var openMenu = document.getElementById('context-openAttachment');
-  var saveMenu = document.getElementById('context-saveAttachment');
-  var decryptOpenMenu = document.getElementById('enigmail_ctxDecryptOpen');
-  var decryptSaveMenu = document.getElementById('enigmail_ctxDecryptSave');
-  if (selectedAttachments.length > 0)
-  {
-    openMenu.removeAttribute('disabled');
-    saveMenu.removeAttribute('disabled');
-
-    if (enigCheckEncryptedAttach(selectedAttachments[0].attachment)) {
-      decryptOpenMenu.removeAttribute('disabled');
-      decryptSaveMenu.removeAttribute('disabled');
-      if (! selectedAttachments[0].attachment.displayName) {
-        selectedAttachments[0].attachment.displayName="message.pgp"
-      }
-    }
-    else {
-      decryptOpenMenu.setAttribute('disabled', true);
-      decryptSaveMenu.setAttribute('disabled', true);
-    }
-  }
-  else
-  {
-    openMenu.setAttribute('disabled', true);
-    saveMenu.setAttribute('disabled', true);
-    decryptOpenMenu.setAttribute('disabled', true);
-    decryptSaveMenu.setAttribute('disabled', true);
-  }
-}
 
 // handle a selected attachment (decrypt & open or save)
 function enigHandleAttachmentSel(actionType) {
@@ -1506,7 +1476,10 @@ function enigHandleAttachmentSel(actionType) {
   var selectedAttachments = attachmentList.selectedItems;
   var anAttachment = selectedAttachments[0].attachment;
 
-  if (actionType=="saveAttachment" || actionType=="openAttachment") {
+  switch (actionType) {
+  case "saveAttachment":
+  case "openAttachment":
+  case "importKey":
     enigHandleAttachment(actionType, anAttachment);
   }
 }
@@ -1559,6 +1532,8 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
   var exitCodeObj = new Object();
   var statusFlagsObj = new Object();
   var errorMsgObj= new Object();
+  var exitStatus = -1;
+
   var enigmailSvc =  GetEnigmailSvc();
   var outFile;
   var rawFileName=callbackArg.attachment.displayName.replace(/\.(asc|pgp|gpg)$/i,"");
@@ -1588,7 +1563,24 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
     }
   }
 
-  var exitStatus=enigmailSvc.decryptAttachment(window, outFile.path,
+  if (callbackArg.actionType == "importKey") {
+    try {
+      var dataLength = new Object();
+      var byteData = callbackArg.ipcBuffer.getByteData(dataLength);
+      exitStatus = enigmailSvc.importKey(parent, 0, byteData, "", errorMsgObj);
+    }
+    catch (ex) {}
+    if (exitStatus == 0) {
+      EnigLongAlert(EnigGetString("successKeyImport")+"\n\n"+errorMsgObj.value);
+    }
+    else {
+      EnigAlert(EnigGetString("failKeyImport")+"\n"+errorMsgObj.value);
+    }
+
+    return;
+  }
+
+  exitStatus=enigmailSvc.decryptAttachment(window, outFile.path,
                                 callbackArg.attachment.displayName, 
                                 callbackArg.ipcBuffer,
                                 exitCodeObj, statusFlagsObj,
@@ -1608,7 +1600,7 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
     }
     else {
       EnigAlert(EnigGetString("failedDecrypt")+"\n\n"+errorMsgObj.value);
-      exiStatus=false;
+      exitStatus=false;
     }
   }
   if (exitStatus) {
@@ -1703,105 +1695,20 @@ function enigAttachmentListClick (elementId, event) {
 function enigHandleUnknownKey() {
   var pubKeyId = "0x" + gEnigSecurityInfo.keyId.substr(8, 8);
 
-  var mesg =  gEnigSecurityInfo.statusInfo + EnigGetString("keyImport",pubKeyId);
+  var mesg =  EnigGetString("pubKeyNeeded") + EnigGetString("keyImport",pubKeyId);
 
   if (EnigConfirm(mesg)) {
-    var recvErrorMsgObj = new Object();
-    var recvFlags = nsIEnigmail.DOWNLOAD_KEY;
-    var progressBar=Components.classes["@mozilla.org/messenger/progress;1"].createInstance(Components.interfaces.nsIMsgProgress);
-    var requestObserver = new EnigRequestObserver(enigReceiveKeyTerminate, {'progressBar': progressBar, 'callType': 1});
-
-    var progressListener = {
-        onStateChange: function(aWebProgress, aRequest, aStateFlags, aStatus)
-        {
-          if (aStateFlags & Components.interfaces.nsIWebProgressListener.STATE_STOP) {
-            if (progressBar.processCanceledByUser)
-              enigReceiveKeyCancel(progressBar);
-          }
-        },
-
-        onProgressChange: function(aWebProgress, aRequest, aCurSelfProgress, aMaxSelfProgress, aCurTotalProgress, aMaxTotalProgress)
-        {},
-
-        onLocationChange: function(aWebProgress, aRequest, aLocation)
-        {},
-
-        onStatusChange: function(aWebProgress, aRequest, aStatus, aMessage)
-        {},
-
-        onSecurityChange: function(aWebProgress, aRequest, state)
-        {},
-
-        QueryInterface : function(iid)
-        {
-          if (iid.equals(Components.interfaces.nsIWebProgressListener) ||
-              iid.equals(Components.interfaces.nsISupportsWeakReference) ||
-              iid.equals(Components.interfaces.nsISupports))
-            return this;
-
-          throw Components.results.NS_NOINTERFACE;
-        }
+    var inputObj = {
+      searchList : [ pubKeyId ]
     };
-    progressBar.registerListener(progressListener);
+    var resultObj = new Object();
 
-    var ipcRequest = EnigReceiveKey(window, msgWindow,
-                      recvFlags, pubKeyId,
-                      progressBar,
-                      requestObserver,
-                      recvErrorMsgObj);
+    EnigDownloadKeys(inputObj, resultObj);
 
-    if (ipcRequest == null) {
-      EnigAlert(EnigGetString("keyImportError")+recvErrorMsgObj.value);
-    }
-    gEnigIpcRequest = ipcRequest;
-  }
-}
-
-function enigReceiveKeyTerminate (terminateArg, ipcRequest) {
-  DEBUG_LOG("enigmailMessengerOverlay.js: receiveKeyTerminate\n");
-
-  if (terminateArg && terminateArg.progressBar) {
-    terminateArg.progressBar.onStateChange(null, null, Components.interfaces.nsIWebProgressListener.STATE_STOP, 0);
-  }
-
-  var keyRetrProcess = gEnigIpcRequest.pipeTransport;
-  var enigmailSvc = GetEnigmailSvc();
-  var exitCode;
-
-  if (keyRetrProcess && !keyRetrProcess.isAttached()) {
-    keyRetrProcess.terminate();
-    exitCode = keyRetrProcess.exitCode();
-    DEBUG_LOG("enigmailMessengerOverlay.js: enigReceiveKeyTerminate: exitCode = "+exitCode+"\n");
-    if (enigmailSvc) {
-      exitCode = enigmailSvc.fixExitCode(exitCode, 0);
+    if (resultObj.importedKeys > 0) {
+      enigMessageReload(false);
     }
   }
-
-  if (exitCode==0) {
-    enigMessageReload(false);
-    if (enigmailSvc) {
-      enigmailSvc.invalidateUserIdList();
-    }    
-  }
-  else {
-    var errorMsg="";
-    try {
-      var keygenConsole = gEnigIpcRequest.stderrConsole.QueryInterface(Components.interfaces.nsIPipeConsole);
-
-      if (keygenConsole && keygenConsole.hasNewData()) {
-        errorMsg = keygenConsole.getData();
-        if (enigmailSvc) {
-          var statusFlagsObj=new Object();
-          var statusMsgObj=new Object();
-          errorMsg=enigmailSvc.parseErrorOutput(errorMsg, statusFlagsObj, statusMsgObj);
-        }
-      }
-    } catch (ex) {}
-    DEBUG_LOG("enigmailMessengerOverlay.js: enigReceiveKeyTerminate: errorMsg="+errorMsg);
-    EnigAlert(EnigGetString("keyImportError")+ errorMsg);
-  }
-  gEnigIpcRequest.close(true);
-
 }
 
 function enigReceiveKeyCancel(progressBar) {
